@@ -27,6 +27,7 @@
 """
 
 import os
+import re
 import subprocess
 from typing import Tuple
 
@@ -279,31 +280,31 @@ def create_database_migration_numbered_style(
         n_sequence_chars: int = 4) -> None:
     """
     Create a new Alembic migration script.
-    
+
     Alembic compares the **state of the database** to the **state of the
     metadata**, and generates a migration that brings the former up to the
     latter. (It does **not** compare the most recent revision to the current
     metadata, so make sure your database is up to date with the most recent
     revision before running this!)
-    
+
     You **must check** that the autogenerated revisions are sensible.
-    
+
     How does it know where to look for the database?
-    
+
         1. This function changes into the directory of the Alembic ``.ini``
            file and calls the external program
-        
+
            .. code-block:: bash
-        
+
                 alembic -c ALEMBIC_INI_FILE revision --autogenerate -m MESSAGE --rev-id REVISION_ID
-                
+
         2. The Alembic ``.ini`` file points (via the ``script_location``
            variable) to a directory containing your ``env.py``. Alembic loads
            this script.
-           
+
         3. That script typically works out the database URL and calls further
-           into the Alembic code.        
-           
+           into the Alembic code.
+
    See http://alembic.zzzcomputing.com/en/latest/autogenerate.html.
 
     Regarding filenames: the default ``n_sequence_chars`` of 4 is like Django
@@ -324,10 +325,12 @@ def create_database_migration_numbered_style(
         n_sequence_chars: number of numerical sequence characters to use in the
             filename/revision (see above).
     """  # noqa
+    file_regex = "\d{" + str(n_sequence_chars) + "}_\S*\.py$"
+
     _, _, existing_version_filenames = next(os.walk(alembic_versions_dir),
                                             (None, None, []))
     existing_version_filenames = [
-        x for x in existing_version_filenames if x != "__init__.py"]
+        x for x in existing_version_filenames if re.match(file_regex, x)]
     log.debug("Existing Alembic version script filenames: {!r}",
               existing_version_filenames)
     current_seq_strs = [x[:n_sequence_chars]
